@@ -256,12 +256,15 @@ class GtkLanguageSelector(LanguageSelectorBase):
         return o
 
     def setSensitive(self, value):
+        win = self.window_main.get_window()
         if value:
             self.window_main.set_sensitive(True)
-            self.window_main.get_window().set_cursor(None)
+            if win:
+                win.set_cursor(None)
         else:
             self.window_main.set_sensitive(False)
-            self.window_main.get_window().set_cursor(Gdk.Cursor.new(Gdk.CursorType.WATCH))
+            if win:
+                win.set_cursor(Gdk.Cursor.new(Gdk.CursorType.WATCH))
         while Gtk.events_pending():
             Gtk.main_iteration()
 
